##  Step 2. Define and add Business Capabilities
Having Business Capabilities in your repository is essential to understand how IT supports the business objectives. Business capabilities represent the organization's high-level activities that contribute to business objectives. It's important to note that Business Capabilities do not represent the departments of your organization; instead, the Organization Fact Sheet serves that purpose.
Defining Business Capabilities and understanding the relationship between Business Capabilities and Applications is an essential part of your portfolio assessment. It helps identify redundancies; for instance, you can analyze which applications serve the same purpose in supporting a capability and whether there is an opportunity for rationalization.
**Tip**
You can import best-practice business capabilities from the reference catalog. For more information, see [Business Capabilities in the Reference Catalog](https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "Import business capabilities from best-practice, industry-specific business capabilities and customize them to suit your organization’s needs.").
![Business Capability Map Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27496aa37a441014968ec28db7f67779_LowRes.png)
Business Capability Landscape Report
**Note**
For German-speaking SAP LeanIX users, we highly recommend the book Business Capabilities by Wolf Pfannenstiel, which is one of the most comprehensive resource on this topic.
It is not an easy task to identify business capabilities, and it is an exercise that is meant to be done hand-in-hand with your business stakeholders. To help you in the process, we have published a [Business Capability Map template![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fdownload%2Fbest-practices-to-define-business-capability-maps "https://www.leanix.net/en/download/best-practices-to-define-business-capability-maps"). Make use of it for a quick start.
Best Practices:
  * Organize business capabilities hierarchically. A capability hierarchy is a structured view of your business capabilities that allows you to see how they relate.
  * It is good practice to start small with a high-level capability map and only move further down to the next level of the hierarchy when required.
  * We recommend working with only two levels or less in Business Capabilities.


After defining your business capabilities, create corresponding Fact Sheets and add the necessary data. This process includes identifying Business Owners and other stakeholders, and gathering and adding all relevant information. Key data to focus on include strategic importance, supporting applications, associated initiatives and projects, and the objectives being fulfilled. This information can help you better understand each capability's impact on your organization.
![Business Capability Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27441da97a441014a5eda94c6d290c67_LowRes.png)
Business Capability Fact Sheet
The efficient way to get the data into your workspace is again with Excel Import/Export capabilities in the Inventory. To learn more, see [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.").
![Getting data through Excel import](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757bf3d7a441014ae20c7322d4e19e7_LowRes.png)
Getting Data Through Excel Import
To learn more about the Business Capability Fact Sheet, see [Business Capability Modeling Guidelines](https://help.sap.com/docs/leanix/ea/business-capability-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "This page covers modeling guidelines for business capabilities. Learn about best practices and applicable use cases, and avoid common antipatterns.").
